@@ -9,12 +9,12 @@ else
     if [ "$(uname)" = "Darwin" ]
     then
         # default to 2.3 on Mac OS X
-        PREF_VER=2.5
+        PREF_VER=2.6
     else
         PREF_VER=
     fi
 fi
-for PY_VER in ${PREF_VER} 2.6 2.5 2.4 2.3 2.2
+for PY_VER in ${PREF_VER} 2.6 2.5
 do
     # used in pick python to use in Builder driver makefile
     export PYTHON=$( which python${PY_VER} )
@@ -26,6 +26,11 @@ do
 done
 unset PREF_VER
 
+if [ "$WC_SVNVERSION" = "" ]
+then
+    export WC_SVNVERSION=svnversion
+fi
+
 export PYCXX=${WORKDIR}/Import/pycxx_${PYCXXVER}
 
 export MEINC_INSTALLER_DIR=${WORKDIR}/Import/MEINC_Installer
@@ -41,4 +46,4 @@ done
 unset _DIR
 ${PYTHON} -c "import sys;print 'Info: Python Version %r' % sys.version"
 ${PYTHON} -c "import pysvn;print 'Info: pysvn Version',pysvn.version"
-${PYTHON} -c "import pysvn;print 'svn version',pysvn.svn_version"
+${PYTHON} -c "import pysvn;print 'Info: svn version',pysvn.svn_version"
