@@ -30,8 +30,9 @@ pkg_filename = 'pysvn_workbench_svn%s-%s' % (svn_version_package_string, wb_vers
 print 'Info: Packageing %s' % pkg_filename
 build_time  = time.time()
 build_time_str = time.strftime( '%d-%b-%Y %H:%M', time.localtime( build_time ) )
-
+year = time.strftime( '%Y', time.localtime( build_time ) )
 tmpdir = os.path.join( os.getcwd(), 'tmp' )
+
 if os.path.exists( tmpdir ):
     print 'Info: Clean up tmp directory'
     os_system( 'rm -rf tmp' )
@@ -74,7 +75,7 @@ f.write('''<html>
 <body>
 <h1>pysvn WorkBench %(wb_version_string)s for Mac OS X and Subversion %(svn_version_string)s</h1>
 
-<h2>Copyright Barry A. Scott (c) 2003-2007</h2>
+<h2>Copyright Barry A. Scott (c) 2003-%(year)s</h2>
 
 <h2>Mail <a href="mailto:barry@barrys-emacs.org">barry@barrys-emacs.org</a></h2>
 
@@ -87,7 +88,7 @@ f.write('''<html>
 f.close()
 
 print 'Info: python bundle'
-os_system( '${PYTHON} make_wb_bundle.py tmp/%s' % pkg_filename)
+os_system( '${PYTHON} -u make_wb_bundle.py tmp/%s' % pkg_filename)
 
 print 'Info: Make Disk Image'
 os_system( 'hdiutil create -srcfolder tmp/%s tmp/tmp.dmg' % pkg_filename )
