@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -28,10 +28,10 @@ import wb_preferences
 import wb_platform_specific
 import wb_exceptions
 import wb_diff_frame
-import wb_show_diff_frame
 import wb_dialogs
 import wb_background_thread
 import wb_shell_commands
+import wb_subversion_report_revision_changes
 
 # 2.8 has the convenient ACCEL_CMD
 # on 2.6 we can add the feature
@@ -250,6 +250,14 @@ class WbApp(wx.App):
     def getPasteData( self ):
         return self.__paste_data
 
+    # called from wb_subversion_history to avoid circlar imports
+    def showReportRevisionChangesFrame( self, project_info, changed_files, info1, info2 ):
+        revision_changes_frame = wb_subversion_report_revision_changes.ReportRevisionChangesFrame(
+                                    self, project_info,
+                                    changed_files, info1, info2 )
+        revision_changes_frame.Show( True )
+
+
     def diffFiles( self, file_left, title_left, file_right, title_right ):
         diff_frame = wb_diff_frame.DiffFrame(
             self, self.frame,
@@ -291,13 +299,22 @@ class WbApp(wx.App):
             return dialog.getLogMessage(), dialog.getForce()
         return None, False
 
-    def addFile( self, title, name, force ):
+    def addFile( self, title, name, force=None ):
         dialog = wb_dialogs.AddDialog( self.frame, title, name, force )
         result = dialog.ShowModal()
         if result == wx.ID_OK:
             return dialog.getForce()
         return None
 
+    def addFolder( self, title, name, force, recursive=None ):
+        dialog = wb_dialogs.AddDialog( self.frame, title, name, force, recursive=recursive )
+        result = dialog.ShowModal()
+        if result == wx.ID_OK:
+            return dialog.getForce(), dialog.getRecursive()
+
+        return None, None
+
+
     def renameFile( self, title, old_name, force=None ):
         dialog = wb_dialogs.RenameFile( self.frame, title, old_name, force )
         result = dialog.ShowModal()
@@ -522,9 +539,16 @@ class RotatingFileHandler(logging.FileHandler):
         """
         if self.maxBytes > 0:                   # are we rolling over?
             msg = "%s\n" % self.format(record)
-            self.stream.seek(0, 2)  #due to non-posix-compliant Windows feature
-            if self.stream.tell() + len(msg) >= self.maxBytes:
+            try:
+                self.stream.seek(0, 2)  #due to non-posix-compliant Windows feature
+                if self.stream.tell() + len(msg) >= self.maxBytes:
+                    self.doRollover()
+
+            except ValueError:
+                # on Windows we get "ValueError: I/O operation on closed file"
+                # when a second copy of workbench is run
                 self.doRollover()
+
         logging.FileHandler.emit(self, record)
 
 class StdoutLogHandler(logging.Handler):
