@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -12,6 +12,7 @@
 '''
 import wx
 import os
+import pysvn
 
 id_log_message_text = wx.NewId()
 id_last_log_message = wx.NewId()
@@ -278,7 +279,7 @@ class GetServerTrust(wx.Dialog):
         return self.save_ctrl.GetValue() != 0
 
 class AddDialog(wx.Dialog):
-    def __init__( self, parent, title, filename, force=None ):
+    def __init__( self, parent, title, filename, force=False, recursive=None ):
         wx.Dialog.__init__( self, parent, -1, title )
 
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
@@ -294,11 +295,20 @@ class AddDialog(wx.Dialog):
         self.g_sizer.Add( self.filename_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.filename_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
 
-        self.force_ctrl = wx.CheckBox( self, -1, "Force add" )
+        self.force_ctrl = wx.CheckBox( self, -1, 'Force Add' )
         self.force_ctrl.SetValue( force )
         self.g_sizer.Add( self.force_ctrl, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( (1, 1) )
 
+        if recursive is not None:
+            self.recursive_ctrl = wx.CheckBox( self, -1, 'Recursive Add' )
+            self.recursive_ctrl.SetValue( recursive )
+            self.g_sizer.Add( self.recursive_ctrl, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
+            self.g_sizer.Add( (1, 1) )
+
+        else:
+            self.recursive_ctrl = None
+
         self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
         self.button_ok.SetDefault()
         self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
@@ -331,8 +341,15 @@ class AddDialog(wx.Dialog):
     def getForce( self ):
         if self.force_ctrl is None:
             return False
+
         return self.force_ctrl.GetValue() != 0
 
+    def getRecursive( self ):
+        if self.recursive_ctrl is None:
+            return False
+
+        return self.recursive_ctrl.GetValue() != 0
+
 class RenameFile(wx.Dialog):
     def __init__( self, parent, title, old_filename, force=None ):
         wx.Dialog.__init__( self, parent, -1, title )
@@ -528,6 +545,94 @@ class NewFile(wx.Dialog):
         else:
             return None
 
+class UpdateTo(wx.Dialog):
+
+    def __init__( self, parent ):
+        wx.Dialog.__init__( self, parent, -1, T_('Update to') )
+
+        self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
+        self.g_sizer.AddGrowableCol( 1 )
+
+        self.newfile_border = wx.StaticBox( self, -1, T_('Update to') )
+        self.newfile_box = wx.StaticBoxSizer( self.newfile_border, wx.VERTICAL )
+
+        # Line 1: checkbox for head revision
+        self.force_checkbox_ctrl = wx.CheckBox( self, -1, T_("HEAD revision") )
+        self.force_checkbox_ctrl.SetValue( True )
+
+        self.newfile_box.Add( self.force_checkbox_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        # Line 2: text entry for giving a revision no. manually
+        self.newfile_box.Add( self.g_sizer, 0, wx.EXPAND )
+
+        self.newfile_text = wx.StaticText( self, -1, T_('Revision:') )
+        self.newfile_ctrl = wx.TextCtrl( self, -1, '' )
+        self.newfile_ctrl.SetSelection( -1, -1 )
+        self.newfile_ctrl.Enable( False )
+
+        self.g_sizer.Add( self.newfile_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
+        self.g_sizer.Add( self.newfile_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        # Line 3: Ok/Cancel button
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
+        self.button_ok.SetDefault()
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
+
+        self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
+        self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
+        self.h_sizer_buttons.Add( self.button_ok, 0, wx.EXPAND|wx.EAST, 15 )
+        self.h_sizer_buttons.Add( self.button_cancel, 0, wx.EXPAND|wx.EAST, 2 )
+
+        self.v_sizer = wx.BoxSizer( wx.VERTICAL )
+        self.v_sizer.Add( self.newfile_box, 0, wx.EXPAND|wx.ALL, 5 )
+        self.v_sizer.Add( self.h_sizer_buttons, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.SetAutoLayout( True )
+        self.SetSizer( self.v_sizer )
+        self.v_sizer.Fit( self )
+        self.Layout()
+
+        self.CentreOnParent()
+
+        # Catch button events
+        wx.EVT_BUTTON( self, wx.ID_OK, self.OnOk )
+        wx.EVT_BUTTON( self, wx.ID_CANCEL, self.OnCancel )
+
+        # Catch checkbox event
+        wx.EVT_CHECKBOX ( self, self.force_checkbox_ctrl.GetId(), self.cbClicked )
+
+    def OnOk( self, event ):
+        # Check revision value
+        if self.force_checkbox_ctrl.GetValue() == False:
+            sval = self.newfile_ctrl.GetValue()
+            if not sval.isdigit():
+                wx.MessageBox( T_('Please enter digits only!'),
+                               style=wx.OK|wx.ICON_ERROR );
+
+                return
+            if int(sval) < 1:
+                wx.MessageBox( T_('Please enter a revision number > 0!'),
+                               style=wx.OK|wx.ICON_ERROR );
+
+                return
+        self.EndModal( wx.ID_OK )
+
+    def OnCancel( self, event ):
+        self.EndModal( wx.ID_CANCEL )
+
+    def cbClicked( self, event ):
+        if self.force_checkbox_ctrl.GetValue():
+            self.newfile_ctrl.Enable(False)
+        else:
+            self.newfile_ctrl.Enable(True)
+
+    def getRevision( self ):
+        if self.force_checkbox_ctrl.GetValue():
+            return pysvn.Revision( pysvn.opt_revision_kind.head )
+        else:
+            rev = int(self.newfile_ctrl.GetValue())
+            return pysvn.Revision( pysvn.opt_revision_kind.number, rev )
+
 class CopyUrl(wx.Dialog):
     def __init__( self, parent, title, copy_from_url, copy_to_url ):
         wx.Dialog.__init__( self, parent, -1, '%s %s' % (title, copy_from_url) )
