@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -99,6 +99,7 @@ class WbFrame(wx.Frame):
         self.menu_actions.Append( wb_ids.id_SP_Properties, T_('Properties...'), T_('Properties...') )
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Update, T_('Update'), T_('Update') )
+        self.menu_actions.Append( wb_ids.id_SP_Update_To, T_('Update to...'), T_('Update to...') )
         self.menu_actions.Append( wb_ids.id_SP_Checkout, T_('Checkout'), T_('Checkout') )
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Checkin, T_('Checkin...'), T_('Checkin...') )
@@ -158,7 +159,7 @@ class WbFrame(wx.Frame):
 
         self.menu_project = wx.Menu()
         self.menu_project.Append( wb_ids.id_Project_Add, T_('Add...'), T_('Project Add') )
-        self.menu_project.Append( wb_ids.id_Project_Update, T_('Update...'), T_('Update Project') )
+        self.menu_project.Append( wb_ids.id_Project_Update, T_('Settings...'), T_('Project Settings') )
         self.menu_project.AppendSeparator()
         self.menu_project.Append( wb_ids.id_Project_Delete, T_('Delete...'), T_('Delete Project') )
 
@@ -408,6 +409,8 @@ class WbFrame(wx.Frame):
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Unlock, self.app.eventWrapper( self.OnUpdateUiSpUnlock ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnSpUpdate ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnUpdateUiSpUpdate ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_Update_To, self.app.eventWrapper( self.OnSpUpdateTo ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Update_To, self.app.eventWrapper( self.OnUpdateUiSpUpdateTo ) )
 
         wx.EVT_MENU( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnSpReportUpdates ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnUpdateUiSpReportUpdates ) )
@@ -501,13 +504,14 @@ class WbFrame(wx.Frame):
 
     # Handler for the About menu command
     def OnCmdAbout(self, event):
-        str_message =    (T_('Work Bench version: %d.%d.%d-%d\n') %
+        ver_str = ('%d.%d.%d-%d\n' %
                     (wb_version.major, wb_version.minor,
-                     wb_version.patch, wb_version.build) +
+                     wb_version.patch, wb_version.build))
+        str_message =    ((T_('Work Bench version: %s') % ver_str) +
                 '\n' + wb_source_control_providers.getProviderAboutStrings() +
                 '\nwxPython %d.%d.%d.%d %s' % wx.VERSION +
                 '\nPython %d.%d.%d %s %d\n' % sys.version_info +
-                T_('\nCopyright Barry Scott (c) 2003-2007. All rights reserved')
+                T_('\nCopyright Barry Scott (c) 2003-2009. All rights reserved')
                 )
         wx.LogMessage( str_message )
 
@@ -1019,11 +1023,11 @@ class WbFrame(wx.Frame):
         event.Enable( self.ui_state_focus.file_exists )
 
     def OnSpReportUpdates( self, event ):
-        return self.Sp_Dispatch( 'OnReportUpdates' )
+        return self.tree_panel.OnReportUpdates()
 
     def OnUpdateUiSpReportUpdates( self, event ):
         self.getUpdateUiState()
-        event.Enable( self.ui_state_focus.versioned )
+        event.Enable( self.ui_state_tree.file_exists )
 
     def OnSpReportLocksWc( self, event ):
         return self.Sp_Dispatch( 'OnReportLocksWc' )
@@ -1033,11 +1037,11 @@ class WbFrame(wx.Frame):
         event.Enable( self.ui_state_focus.versioned )
 
     def OnSpReportBranchChanges( self, event ):
-        return self.Sp_Dispatch( 'OnReportBranchChanges' )
+        return self.tree_panel.OnReportBranchChanges()
 
     def OnUpdateUiSpReportBranchChanges( self, event ):
         self.getUpdateUiState()
-        event.Enable( self.ui_state_focus.versioned )
+        event.Enable( self.ui_state_tree.file_exists )
 
     def OnSpReportLocksRepos( self, event ):
         return self.Sp_Dispatch( 'OnReportLocksRepos' )
@@ -1095,6 +1099,12 @@ class WbFrame(wx.Frame):
         else:
             event.Enable( False )
 
+    def OnSpUpdateTo( self, event ):
+        return self.Sp_Dispatch( 'OnSpUpdateTo' )
+
+    def OnUpdateUiSpUpdateTo( self, event ):
+        self.OnUpdateUiSpUpdate(event)
+
     #----------------------------------------
     def Sp_Dispatch( self, sp_func_name ):
         self.clearUpdateUiState()
