@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -69,35 +69,19 @@ class WbListCtrl(wx.ListCtrl):
         wx.ListCtrl.__init__( self, parent, list_id,
                                 style=wx.LC_REPORT|wx.LC_HRULES|wx.LC_VIRTUAL )
         self.parent = parent
-        imSize = (16,16)
-        il = wx.ImageList(*imSize)
-        self.il_folder = il.Add( wx.ArtProvider.GetBitmap( wx.ART_FOLDER, size=imSize ) )
-        self.il_file = il.Add( wx.ArtProvider.GetBitmap( wx.ART_NORMAL_FILE, size=imSize ) )
+        image_size = (16,16)
+        il = wx.ImageList( *image_size )
+        self.il_folder = il.Add( wx.ArtProvider.GetBitmap( wx.ART_FOLDER, size=image_size ) )
+        self.il_file = il.Add( wx.ArtProvider.GetBitmap( wx.ART_NORMAL_FILE, size=image_size ) )
         self.AssignImageList( il, wx.IMAGE_LIST_SMALL )
 
-        self.doSelect = self.SelectFirstAtStart
-
-    def SelectFirstAtStart(self):
-        """
-        A simple hack to select the first item, but delay it until we
-        know we have items.  It's called from SetItemCount only the
-        first time it is called.
-        """
-        wx.CallAfter(self.Select, 0)
-        self.doSelect = None
-
-    def SetItemCount(self, count):
-        if self.doSelect and count > 0:
-            self.doSelect()
-        return wx.ListCtrl.SetItemCount(self, count)
-        
-    def OnGetItemText(self, item, col):
+    def OnGetItemText( self, item, col ):
         if self.parent.list_handler is not None:
             return self.parent.list_handler.OnGetItemText( item, col )
         else:
             return ''
 
-    def OnGetItemImage(self, item):
+    def OnGetItemImage( self, item ):
         if self.parent.list_handler is not None:
             if self.parent.list_handler.isItemImageFolder( item ):
                 return self.il_folder
@@ -107,7 +91,7 @@ class WbListCtrl(wx.ListCtrl):
 
         return -1
 
-    def OnGetItemAttr(self, item):
+    def OnGetItemAttr( self, item ):
         if self.parent.list_handler is not None:
             return self.parent.list_handler.OnGetItemAttr( item )
         else:
@@ -182,6 +166,15 @@ class WbListPanelCommon(wx.Panel):
         self.last_char_timestamp = 0
         self.inc_search_string = ''
 
+        self.__first_time_select_allowed = True
+
+    def firstTimeSelect( self ):
+        if self.__first_time_select_allowed:
+            if self.list_handler is not None:
+                if len( self.list_handler.all_files ) > 0:
+                    wx.CallAfter( self.list_ctrl.Select, 0 )
+        self.__first_time_select_allowed = False
+
     def __repr__( self ):
         return '<WbListPanelCommon %r>' % self.list_handler
 
@@ -297,6 +290,8 @@ class WbListPanelCommon(wx.Panel):
         self.list_handler.setupColumns()
         self.list_handler.updateStatus()
 
+        self.list_ctrl.SetBackgroundColour( self.list_handler.getBackgroundColour() )
+
         self.filter_field = ''
         self.header_panel.clearFilterText()
 
@@ -456,6 +451,9 @@ class WbListPanelCommon(wx.Panel):
     def OnSpUpdate( self ):
         return self.Sp_Dispatch( 'Cmd_File_Update' )
 
+    def OnSpUpdateTo( self ):
+        return self.Sp_Dispatch( 'Cmd_File_Update_To' )
+
     def Sp_Dispatch( self, sp_func_name ):
         self.app.trace.info( 'WbListPanel.Sp_Dispatch( %s ) event' % sp_func_name )
         if not self.list_handler:
@@ -466,6 +464,16 @@ class WbListPanelCommon(wx.Panel):
         self.app.trace.info( 'WbListPanel.Sp_Dispatch( %s ) calling' % sp_func_name )
         return sp_func( self.getSelectedRows() )
 
+    def selectAll( self ):
+        item_index = -1
+        while True:
+            item_index = self.list_ctrl.GetNextItem( item_index, wx.LIST_NEXT_ALL )
+            if item_index < 0:
+                break
+
+            focused = self.list_ctrl.GetItemState( item_index, wx.LIST_STATE_FOCUSED )
+            self.list_ctrl.SetItemState( item_index, wx.LIST_STATE_SELECTED | focused, wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED )
+
     def getSelectedRows( self ):
         all_rows = []
         item_index = -1
