@@ -18,7 +18,7 @@ import locale
 # help debug when stdout goes nowhere useful
 # Mac OS X and Windows are the main problems
 if( os.environ.get( 'PYSVN_WORKBENCH_STDOUT_LOG', None )
-or sys.platform == 'darwin' ):
+or (sys.platform == 'darwin' and '--noredirect' not in sys.argv) ):
     try:
         sys.stdout = file( os.environ.get( 'PYSVN_WORKBENCH_STDOUT_LOG', '/tmp/workbench.tmp' ), 'w' )
         sys.stderr = sys.stdout
@@ -27,10 +27,10 @@ or sys.platform == 'darwin' ):
     except EnvironmentError:
         pass
 
-# make sure that we get 2.6 and not an earlier version
+# make sure that we get 2.8 and not an earlier version
 try:
     import wxversion
-    wxversion.select('2.6')
+    wxversion.select( ['2.8'] )
 except:
     pass
 
