@@ -13,9 +13,13 @@
 
 '''
 import os
+import sys
 
 def getApplicationDir():
     return os.path.join( os.environ['HOME'], 'Library/Preferences/org.tigris.pysvn.Workbench' )
 
+def getLocalePath( app ):
+    return os.path.join( app.app_dir, 'locale' )
+
 def getNullDevice():
     return '/dev/null'
