@@ -23,5 +23,8 @@ def getApplicationDir():
                 0, SHGFP_TYPE_CURRENT )
     return os.path.join( app_folder, 'WorkBench' )
 
+def getLocalePath( app ):
+    return os.path.join( app.app_dir, 'locale' )
+
 def getNullDevice():
     return 'NUL'
