@@ -1,7 +1,7 @@
 '''
 
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -370,7 +370,7 @@ class GetIndexedOption:
         return float( self.getstr( name ) )
 
     def getbool( self, name ):
-        return self.getstr( name ) == 'true'
+        return self.getstr( name ).lower() == 'true'
 
 class ProjectsPreferences(PreferenceSection):
     def __init__( self, app ):
@@ -470,18 +470,20 @@ class BookmarksPreferences(PreferenceSection):
 
         set_option = SetOption( pref_data, self.section_name )
 
-        all_bookmarks = self.all_bookmarks.values()
+        all_bookmarks = self.all_bookmarks.items()
         all_bookmarks.sort( self.__cmpBookmarksByMenuAndName )
 
-        for bookmark in all_bookmarks:
+        for bookmark_name, bookmark in all_bookmarks:
             pref_dict = {}
-            pref_dict[ 'bookmark_name' ] = bookmark.wc_path
+            pref_dict[ 'bookmark_name' ] = bookmark_name
 
             bookmark.writePreferences( pref_dict )
 
             pref_data.append_dict( self.section_name, 'bookmark', pref_dict )
 
-    def __cmpBookmarksByMenuAndName( self, a, b ):
+    def __cmpBookmarksByMenuAndName( self, a_kv, b_kv ):
+        a = a_kv[1]
+        b = b_kv[1]        
         if a.menu_folder != '':
             a_key = a.menu_folder + '\001' + a.menu_name
         else:
