@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright ( c ) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -561,8 +561,8 @@ class ListColumnsPage(PagePanel):
         try:
             width = int(self.width_text_ctrl.GetValue())
         except ValueError:
-            wx.MessageBox( T_('Width for %s must be an number between %d and %d') %
-                        (info.name, info.min_width, info.max_width),
+            wx.MessageBox( T_('Width for %(name)s must be an number between %(min)d and %(max)d') %
+                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
@@ -572,8 +572,8 @@ class ListColumnsPage(PagePanel):
         and width <= info.max_width ):
             info.width = width
         else:
-            wx.MessageBox( T_('Width for %s must be between %d and %d') %
-                        (info.name, info.min_width, info.max_width),
+            wx.MessageBox( T_('Width for %(name)s must be between %(min)d and %(max)d') %
+                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
@@ -619,8 +619,8 @@ class ListColumnsPage(PagePanel):
         try:
             width = int(self.width_text_ctrl.GetValue())
         except ValueError:
-            wx.MessageBox( T_('Width for %s must be an number between %d and %d') %
-                        (info.name, info.min_width, info.max_width),
+            wx.MessageBox( T_('Width for %(name)s must be an number between %(min)d and %(max)d') %
+                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
@@ -632,8 +632,8 @@ class ListColumnsPage(PagePanel):
             index = self.included_list.FindItem( -1, info.name )
             self.included_list.SetStringItem( index, 1, str(width) )
         else:
-            wx.MessageBox( T_('Width for %s must be between %d and %d') %
-                        (info.name, info.min_width, info.max_width),
+            wx.MessageBox( T_('Width for %(name)s must be between %(min)d and %(max)d') %
+                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
