@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -21,7 +21,7 @@ import os
 #    registered providers to put up provider specific
 #    dialog.
 #
-wc_path_browse_button_id = wx.NewId()
+wc_path_browse_id = wx.NewId()
 wc_path_text_ctrl_id = wx.NewId()
 name_text_ctrl_id = wx.NewId()
 url_trunk_path_text_ctrl_id = wx.NewId()
@@ -37,12 +37,13 @@ class ProjectDialog(wx.Dialog):
         self.client = pysvn.Client()
         self.client.exception_style = 1
 
+        self.list_background_colour = None
+
         # get the list of names to use in the validation
         pi_list = self.app.prefs.getProjects().getProjectList()
         self.pi_names = [pi.project_name for pi in pi_list]
 
-        self.g_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
-        self.g_sizer.AddGrowableCol( 1 )
+        self.g_sizer = wx.GridBagSizer( 5, 20 )
 
         self.border = wx.StaticBox( self, -1, 'Project' )
         self.box = wx.StaticBoxSizer( self.border, wx.VERTICAL )
@@ -51,47 +52,53 @@ class ProjectDialog(wx.Dialog):
         self.name_label = wx.StaticText( self, -1, 'Project Name:', style=wx.ALIGN_RIGHT )
         self.name_ctrl = wx.TextCtrl( self, -1, '', size=(400,-1) )
 
-        self.g_sizer.Add( self.name_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
-        self.g_sizer.Add( self.name_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
-        self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
+        self.g_sizer.Add( self.name_label, (0,0), (1,1), wx.ALIGN_RIGHT )
+        self.g_sizer.Add( self.name_ctrl,  (0,1), (1,2), wx.EXPAND )
 
-        self.wc_path_browse_button = wx.Button( self, wc_path_browse_button_id, " Browse... ")
+        self.wc_path_browse = wx.Button( self, wc_path_browse_id, " Browse... ")
 
         self.wc_path_label = wx.StaticText(self, -1, 'Working copy Path:', style=wx.ALIGN_RIGHT )
         self.wc_path_ctrl = wx.TextCtrl(self, wc_path_text_ctrl_id, '' )
 
-        self.g_sizer.Add( self.wc_path_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
-        self.g_sizer.Add( self.wc_path_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
-        self.g_sizer.Add( self.wc_path_browse_button, 0, wx.EXPAND )
+        self.g_sizer.Add( self.wc_path_label,  (1,0), (1,1), wx.ALIGN_RIGHT )
+        self.g_sizer.Add( self.wc_path_ctrl,   (1,1), (1,2), wx.EXPAND )
+        self.g_sizer.Add( self.wc_path_browse, (1,3), (1,1)  )
 
         self.url_trunk_label = wx.StaticText( self, -1, 'Subversion Trunk URL:', style=wx.ALIGN_RIGHT )
         self.url_trunk_ctrl = wx.TextCtrl( self, url_trunk_path_text_ctrl_id, '' )
 
+        self.g_sizer.Add( self.url_trunk_label, (2,0), (1,1), wx.ALIGN_RIGHT )
+        self.g_sizer.Add( self.url_trunk_ctrl,  (2,1), (1,2), wx.EXPAND )
+
         self.url_tags_label = wx.StaticText( self, -1, 'Subversion Tags URL:', style=wx.ALIGN_RIGHT )
         self.url_tags_ctrl = wx.TextCtrl( self, url_tags_path_text_ctrl_id, '' )
 
+        self.g_sizer.Add( self.url_tags_label, (3,0), (1,1), wx.ALIGN_RIGHT )
+        self.g_sizer.Add( self.url_tags_ctrl,  (3,1), (1,2), wx.EXPAND )
+
         self.url_branches_label = wx.StaticText( self, -1, 'Subversion Branches URL:', style=wx.ALIGN_RIGHT )
         self.url_branches_ctrl = wx.TextCtrl( self, url_tags_path_text_ctrl_id, '' )
 
-        self.g_sizer.Add( self.url_trunk_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
-        self.g_sizer.Add( self.url_trunk_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
-        self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
-
-        self.g_sizer.Add( self.url_tags_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
-        self.g_sizer.Add( self.url_tags_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
-        self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
-
-        self.g_sizer.Add( self.url_branches_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
-        self.g_sizer.Add( self.url_branches_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
-        self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
+        self.g_sizer.Add( self.url_branches_label, (4,0), (1,1), wx.ALIGN_RIGHT )
+        self.g_sizer.Add( self.url_branches_ctrl,  (4,1), (1,2), wx.EXPAND )
 
         self.newfile_dir_label = wx.StaticText( self, -1, "New File Template Folder: ", style=wx.ALIGN_RIGHT)
         self.newfile_dir_ctrl = wx.TextCtrl( self, -1, '' )
         self.newfile_dir_browse = wx.Button( self, -1, " Browse... ")
 
-        self.g_sizer.Add( self.newfile_dir_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
-        self.g_sizer.Add( self.newfile_dir_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
-        self.g_sizer.Add( self.newfile_dir_browse, 0, wx.EXPAND )
+        self.g_sizer.Add( self.newfile_dir_label,  (5,0), (1,1), wx.ALIGN_RIGHT )
+        self.g_sizer.Add( self.newfile_dir_ctrl,   (5,1), (1,2), wx.EXPAND )
+        self.g_sizer.Add( self.newfile_dir_browse, (5,3), (1,1) )
+
+        self.list_background_colour_label = wx.StaticText( self, -1, "Background Colour: ", style=wx.ALIGN_RIGHT)
+        self.list_background_colour_ctrl = wx.CheckBox( self, -1, "Use custom background colour" )
+        self.list_background_colour_example = wx.StaticText( self, -1, "Example", style=wx.ALIGN_CENTER )
+        self.list_background_colour_picker = wx.Button( self, -1, " Pick Colour... ")
+
+        self.g_sizer.Add( self.list_background_colour_label,   (6,0), (1,1), wx.ALIGN_RIGHT )
+        self.g_sizer.Add( self.list_background_colour_ctrl,    (6,1), (1,1), wx.EXPAND )
+        self.g_sizer.Add( self.list_background_colour_example, (6,2), (1,1), wx.ALIGN_CENTER|wx.EXPAND )
+        self.g_sizer.Add( self.list_background_colour_picker,  (6,3), (1,1) )
 
         self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
         self.button_ok.SetDefault()
@@ -115,12 +122,15 @@ class ProjectDialog(wx.Dialog):
 
         wx.EVT_BUTTON( self, wx.ID_OK, self.OnOk )
         wx.EVT_BUTTON( self, wx.ID_CANCEL, self.OnCancel )
-        wx.EVT_BUTTON( self, wc_path_browse_button_id, self.OnBrowseWorkingCopyDir )
+        wx.EVT_BUTTON( self, wc_path_browse_id, self.OnBrowseWorkingCopyDir )
         wx.EVT_TEXT( self, wc_path_text_ctrl_id, self.updateControls )
         wx.EVT_TEXT( self, url_trunk_path_text_ctrl_id, self.updateControls )
         wx.EVT_TEXT( self, url_tags_path_text_ctrl_id, self.updateControls )
         wx.EVT_BUTTON( self, self.newfile_dir_browse.GetId(), self.OnBrowseNewFileTemplateDir )
 
+        wx.EVT_BUTTON( self, self.list_background_colour_picker.GetId(), self.OnPickColour )
+        wx.EVT_CHECKBOX( self, self.list_background_colour_ctrl.GetId(), self.OnUseColourClicked )
+
         self._update_controls_lock = False
 
     def updateControls( self, event=None ):
@@ -245,6 +255,34 @@ class ProjectDialog(wx.Dialog):
 
         self.updateControls()
 
+    def OnUseColourClicked( self, event ):
+        if self.list_background_colour_ctrl.GetValue():
+            self.list_background_colour_picker.Enable( True )
+        else:
+            self.list_background_colour_picker.Enable( False )
+
+    def OnPickColour( self, event ):
+        colour_data = wx.ColourData()
+        colour_data.SetChooseFull( True )
+        colour_data.SetColour( self.list_background_colour )
+
+        dlg = wx.ColourDialog( self, colour_data )
+
+        if dlg.ShowModal() == wx.ID_OK:
+
+            # If the user selected OK, then the dialog's wx.ColourData will
+            # contain valid information. Fetch the data ...
+            data = dlg.GetColourData()
+            self.list_background_colour = data.GetColour().Get()
+
+            # ... then do something with it. The actual colour data will be
+            # returned as a three-tuple (r, g, b) in this particular case.
+
+        dlg.Destroy()
+
+        self.list_background_colour_example.SetBackgroundColour( self.list_background_colour )
+        self.list_background_colour_example.Refresh( True )
+
     def getProjectInfo( self ):
         provider = wb_source_control_providers.getProvider( 'subversion' )
         pi = provider.getProjectInfo( self.app )
@@ -256,11 +294,13 @@ class ProjectDialog(wx.Dialog):
             tags_url=self.url_tags_ctrl.GetValue().strip(),
             branches_url=self.url_branches_ctrl.GetValue().strip() )
 
+        pi.setBackgroundColour( self.list_background_colour_ctrl.GetValue(), self.list_background_colour )
+
         return pi
 
 class UpdateProjectDialog(ProjectDialog):
     def __init__( self, app, parent, project_info ):
-        ProjectDialog.__init__( self, app, parent, 'Update Project' )
+        ProjectDialog.__init__( self, app, parent, 'Project Settings' )
 
         self.project_info = project_info
 
@@ -272,6 +312,15 @@ class UpdateProjectDialog(ProjectDialog):
         self.url_tags_ctrl.SetValue( self.project_info.tags_url )
         self.newfile_dir_ctrl.SetValue( self.project_info.new_file_template_dir )
 
+        if self.project_info.use_background_colour:        
+            self.list_background_colour = self.project_info.background_colour
+        else:
+            self.list_background_colour = (255,255,255)
+
+        self.list_background_colour_ctrl.SetValue( self.project_info.use_background_colour )
+        self.list_background_colour_example.SetBackgroundColour( self.list_background_colour )
+        self.list_background_colour_picker.Enable( self.project_info.use_background_colour )
+
         self.updateControls()
 
 class AddProjectState:
@@ -425,11 +474,11 @@ class WorkingCopyExistsPage(TitledPage):
 
         self.wc_path_label = wx.StaticText(self, -1, 'Working copy Path:', style=wx.ALIGN_RIGHT )
         self.wc_path_ctrl = wx.TextCtrl(self, wc_path_text_ctrl_id, '' )
-        self.wc_path_browse_button = wx.Button( self, wc_path_browse_button_id, " Browse... ")
+        self.wc_path_browse = wx.Button( self, wc_path_browse_id, " Browse... ")
 
         self.g_sizer.Add( self.wc_path_label, 0, wx.EXPAND|wx.ALL|wx.ALIGN_BOTTOM, 5 )
         self.g_sizer.Add( self.wc_path_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_BOTTOM, 3 )
-        self.g_sizer.Add( self.wc_path_browse_button, 0, wx.EXPAND )
+        self.g_sizer.Add( self.wc_path_browse, 0, wx.EXPAND )
 
         self.g_sizer.Add( (10,10) )
         self.g_sizer.Add( (400,10) )
@@ -444,7 +493,7 @@ class WorkingCopyExistsPage(TitledPage):
 
         self.sizer.Add( self.g_sizer, 0, wx.ALL, 5 )
 
-        wx.EVT_BUTTON( self, wc_path_browse_button_id, self.OnBrowseWorkingCopyDir )
+        wx.EVT_BUTTON( self, wc_path_browse_id, self.OnBrowseWorkingCopyDir )
         wx.EVT_TEXT( self, wc_path_text_ctrl_id, self.updateControls )
 
         self._update_controls_lock = False
@@ -580,11 +629,11 @@ class WorkingCopyCreatePage(TitledPage):
 
         self.wc_path_label = wx.StaticText(self, -1, 'Working copy Path:', style=wx.ALIGN_RIGHT )
         self.wc_path_ctrl = wx.TextCtrl(self, wc_path_text_ctrl_id, '' )
-        self.wc_path_browse_button = wx.Button( self, wc_path_browse_button_id, " Browse... ")
+        self.wc_path_browse = wx.Button( self, wc_path_browse_id, " Browse... ")
 
         self.g_sizer.Add( self.wc_path_label, 0, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.wc_path_ctrl, 0, wx.EXPAND|wx.ALL, 3 )
-        self.g_sizer.Add( self.wc_path_browse_button, 0, wx.EXPAND )
+        self.g_sizer.Add( self.wc_path_browse, 0, wx.EXPAND )
 
         self.g_sizer.Add( (10,10) )
         self.g_sizer.Add( (400,10) )
@@ -598,7 +647,7 @@ class WorkingCopyCreatePage(TitledPage):
         self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
         self.sizer.Add( self.g_sizer, 0, wx.ALL, 5 )
 
-        wx.EVT_BUTTON( self, wc_path_browse_button_id, self.OnBrowseWorkingCopyDir )
+        wx.EVT_BUTTON( self, wc_path_browse_id, self.OnBrowseWorkingCopyDir )
 
 
     def loadState( self, state ):
