@@ -15,6 +15,7 @@ import win32con
 import win32api
 import os
 import string
+import subprocess
 
 def getTerminalProgramList():
     return ['CMD']
@@ -37,10 +38,19 @@ def EditFile( app, project_info, filename ):
 
     app.log.info( command_line )
     CreateProcess( app, command_line, project_info.getWorkingDir() )
-    
+
+def GuiDiffFiles( app, options ):
+    cmd_line = '"%s" %s' % (app.prefs.getDiffTool().gui_diff_tool, options)
+    app.log.info( cmd_line )
+    CreateProcess( app, cmd_line, os.path.curdir )
+
+def ShellDiffFiles( app, options ):
+    cmd_line = '"%s" %s' % (app.prefs.getDiffTool().shell_diff_tool, options)
+    app.log.info( cmd_line )
+    return __run_command_with_output( cmd_line )
 
 def ShellOpen( app, project_info, filename ):
-    print 'Open',filename
+    app.log.info( 'Open %s' % filename )
     try:
         win32api.ShellExecute( 0, 'open',
                     filename, '',
@@ -98,17 +108,17 @@ def CreateProcess( app, command_line, current_dir ):
             (
             None,
             command_line,
-            None,                # processAttributes
-            None,                # threadAttributes , 
-            0,                # bInheritHandles ,
+            None,               # processAttributes
+            None,               # threadAttributes , 
+            0,                  # bInheritHandles ,
             win32con.CREATE_NEW_CONSOLE,    # dwCreationFlags ,
-            None,                # newEnvironment ,
-            current_dir,            # currentDirectory ,
-            si                # startupinfo
+            None,               # newEnvironment ,
+            current_dir,        # currentDirectory ,
+            si                  # startupinfo
             )
     except win32process.error, detail:
         app.log.error( 'Create process failed for command - %s\n'
-                'Reason %s' % (command_line, detail) )
+                        'Reason %s' % (command_line, detail) )
 
 def ensureDirectory( app, current_dir ):
     if not os.path.exists( current_dir ):
@@ -124,3 +134,21 @@ def ensureDirectory( app, current_dir ):
         return 0
 
     return 1
+
+def __run_command_with_output( command_line ):
+    err_prefix = 'error running %s' % command_line
+    try:
+        proc = subprocess.Popen(
+                    command_line,
+                    bufsize=-1,
+                    stdin=subprocess.PIPE,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT
+                    )
+        all_output = proc.stdout.read()
+        proc.wait()
+
+        return all_output
+
+    except EnvironmentError, e:
+        return '%s - %s' % (err_prefix, str(e))
