@@ -56,6 +56,8 @@ class ProjectInfo:
         self.new_file_template_dir = ''
         self.menu_name = None
         self.menu_folder = ''
+        self.use_background_colour = False
+        self.background_colour = (255,255,255)
 
     def init( self, project_name, **kws ):
         self.project_name = project_name
@@ -64,19 +66,48 @@ class ProjectInfo:
         # return tree if pi is a child of this pi
         raise wb_exceptions.InternalError( 'isChild not implemented' )
 
+    def setBackgroundColour( self, use, colour ):
+        self.use_background_colour = use
+        self.background_colour = colour
+
+
     def readPreferences( self, get_option ):
         if get_option.has( 'new_file_template_dir' ):
             self.new_file_template_dir = get_option.getstr( 'new_file_template_dir' )
+
         if get_option.has( 'menu_folder' ):
             self.menu_folder = get_option.getstr( 'menu_folder' )
+
         if get_option.has( 'menu_name' ):
             self.menu_name = get_option.getstr( 'menu_name' )
 
+        if get_option.has( 'background_colour_red' ):
+            self.background_colour =    (get_option.getint( 'background_colour_red' )
+                                        ,get_option.getint( 'background_colour_green' )
+                                        ,get_option.getint( 'background_colour_blue' ))
+
+        else:
+            self.background_colour = (255,255,255)
+
+        if get_option.has( 'use_background_colour' ):
+            self.use_background_colour = get_option.getbool( 'use_background_colour' )
+
+        else:
+            self.use_background_colour = False
+
     def writePreferences( self, pref_dict ):
         pref_dict[ 'provider' ] = self.provider_name
         pref_dict[ 'name' ] = self.project_name
+
         if self.new_file_template_dir not in [None,'']:
             pref_dict[ 'new_file_template_dir' ] = self.new_file_template_dir
+
         if self.menu_name is not None:
             pref_dict[ 'menu_name' ] = self.menu_name
         pref_dict[ 'menu_folder' ] = self.menu_folder
+
+        if self.use_background_colour:
+            pref_dict[ 'use_background_colour' ] = self.use_background_colour
+            pref_dict[ 'background_colour_red' ] = self.background_colour[0]
+            pref_dict[ 'background_colour_green' ] = self.background_colour[1]
+            pref_dict[ 'background_colour_blue' ] = self.background_colour[2]
