@@ -95,7 +95,10 @@ def subversionDiffFiles(
         or path_info.revision.kind == pysvn.opt_revision_kind.working ):
             if not os.path.exists( path_info.path ):
                 app.log_error( '"%s" does not exist.' % path_info.path )
-                return
+                fd, path_info.path = tempfile.mkstemp( suffix=os.path.basename( path_info.path ) )
+                os.close( fd )
+                # keep track of the temp file
+                app.all_temp_files.append( path_info.path )
 
             if os.path.isdir( path_info.path ):
                 app.log_error( '"%s" refers to a directory.' % path_info.path )
@@ -131,9 +134,6 @@ def subversionDiffFiles(
         except IOError, e:
             app.log_error( e )
 
-        except pysvn.ClientError, e:
-            app.log_client_error( e )
-
         yield app.foregroundProcess
 
         if ok:
@@ -162,9 +162,6 @@ def subversionDiffFiles(
         except IOError, e:
             app.log_error( e )
 
-        except pysvn.ClientError, e:
-            app.log_client_error( e )
-
         yield app.foregroundProcess
 
         if ok:
@@ -174,17 +171,14 @@ def subversionDiffFiles(
         yield app.backgroundProcess
 
         try:
-            all_old_lines = __getFileContents( project_info, old_path_info )
-            all_new_lines = __getFileContents( project_info, new_path_info )
+            all_old_lines = __getFileContents( app, project_info, old_path_info )
+            all_new_lines = __getFileContents( app, project_info, new_path_info )
 
             ok = True
 
         except IOError, e:
             app.log_error( e )
 
-        except pysvn.ClientError, e:
-            app.log_client_error( e )
-
         yield app.foregroundProcess
 
         # built-in
@@ -283,64 +277,74 @@ def __processExternalCommandOptions( app, options, old_filename, old_title, new_
     return options
 
 #
-#   throws IOError and pysvn.ClientError
+#   throws IOError.
 #
-def __getFileContents( project_info, path_info ):
-    if path_info.revision is None or path_info.revision.kind == pysvn.opt_revision_kind.working:
-        all_content_lines = wb_read_file.readFileContentsAsUnicode( path_info.path ).split('\n')
+def __getFileContents( app, project_info, path_info ):    
+    all_content_lines = ''
+    try:
+       if path_info.revision is None or path_info.revision.kind == pysvn.opt_revision_kind.working:
+           all_content_lines = wb_read_file.readFileContentsAsUnicode( path_info.path ).split('\n')
+    
+       else:
+           if path_info.revision.kind == pysvn.opt_revision_kind.base:
+               all_content_lines = project_info.client_bg.cat(
+                   url_or_path=path_info.path,
+                   revision=path_info.revision )
+    
+           else:
+               if path_info.peg_revision is not None:
+                   all_content_lines = project_info.client_bg.cat(
+                       url_or_path=path_info.peg_path,
+                       revision=path_info.revision,
+                       peg_revision=path_info.peg_revision )
+    
+               else:
+                   all_content_lines = project_info.client_bg.cat(
+                       url_or_path=path_info.path,
+                       revision=path_info.revision )
+    
+           all_content_lines = wb_read_file.contentsAsUnicode( all_content_lines ).split( '\n' ) 
 
-    else:
-        if path_info.revision.kind == pysvn.opt_revision_kind.base:
-            all_contents = project_info.client_bg.cat(
-                url_or_path=path_info.path,
-                revision=path_info.revision )
-
-        else:
-            if path_info.peg_revision is not None:
-                all_contents = project_info.client_bg.cat(
-                    url_or_path=path_info.peg_path,
-                    revision=path_info.revision,
-                    peg_revision=path_info.peg_revision )
-
-            else:
-                all_contents = project_info.client_bg.cat(
-                    url_or_path=path_info.path,
-                    revision=path_info.revision )
-
-        all_content_lines = wb_read_file.contentsAsUnicode( all_contents ).split( '\n' ) 
+    except pysvn.ClientError, e:
+        app.log_client_error( e )
+   
 
     return all_content_lines
 
 #
-#   throws IOError and pysvn.ClientError
+#   throws IOError.
 #
 def __getLocalFilename( app, project_info, path_info ):
     rev_description = ''
-    if path_info.revision is None or path_info.revision.kind == pysvn.opt_revision_kind.working:
-        return path_info.path
+    all_content = ''
+    try:
+        if path_info.revision is None or path_info.revision.kind == pysvn.opt_revision_kind.working:
+            return path_info.path
 
-    elif path_info.revision.kind == pysvn.opt_revision_kind.base:
-        rev_description = 'BASE'
-        all_content = project_info.client_bg.cat(
-                url_or_path=path_info.path,
-                revision=path_info.revision )
-
-    else:
-        if path_info.revision.kind == pysvn.opt_revision_kind.head:
-            rev_description = 'HEAD'
-        else:
-            rev_description = 'R%d' % path_info.revision.number
-
-        if path_info.peg_revision is not None:
-            all_content = project_info.client_bg.cat(
-                    url_or_path=path_info.peg_path,
-                    peg_revision=path_info.peg_revision,
-                    revision=path_info.revision )
-        else:
+        elif path_info.revision.kind == pysvn.opt_revision_kind.base:
+            rev_description = 'BASE'
             all_content = project_info.client_bg.cat(
                     url_or_path=path_info.path,
                     revision=path_info.revision )
 
+        else:
+            if path_info.revision.kind == pysvn.opt_revision_kind.head:
+                rev_description = 'HEAD'
+            else:
+                rev_description = 'R%d' % path_info.revision.number
+
+            if path_info.peg_revision is not None:
+                all_content = project_info.client_bg.cat(
+                        url_or_path=path_info.peg_path,
+                        peg_revision=path_info.peg_revision,
+                        revision=path_info.revision )
+            else:
+                all_content = project_info.client_bg.cat(
+                        url_or_path=path_info.path,
+                        revision=path_info.revision )
+    except pysvn.ClientError, e:
+        app.log_client_error( e )
+
     # create a temp file with a name that is based on the original filename
     prefix = 'tmp-%s-%s-' % (os.path.basename( path_info.path ), rev_description)
     suffix = os.path.splitext( path_info.path )[1]
