@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -14,6 +14,7 @@ import wx
 import wx.lib.splitter
 import wx.calendar
 
+import os
 import tempfile
 import time
 import types
@@ -27,6 +28,7 @@ import wb_config
 
 id_view_cmd = wx.NewId()
 id_diff_cmd = wx.NewId()
+id_revision_changes_cmd = wx.NewId()
 id_list = wx.NewId()
 id_paths = wx.NewId()
 
@@ -94,8 +96,16 @@ def getHistoryEntries( project_info, filename, limit, revision_end, include_tags
                     limit=limit,
                     revision_end=revision_end )
 
+    # Settings an end date can lead to no entries
+    if len( all_log_entries ) == 0:
+        return info.URL, all_history_entries
+
     repos_path = info.URL[len(info.repos_root_URL):]
     for log in all_log_entries:
+        # author is optional
+        if 'author' not in log:
+            log.author = ''
+
         all_history_entries.append(
             LogEntry(
                 log.revision.number,
@@ -125,6 +135,10 @@ def getHistoryEntries( project_info, filename, limit, revision_end, include_tags
             all_tag_names = set()
 
             for log in project_info.client_bg.log( tags_url, discover_changed_paths=True ):
+                # author is optional
+                if 'author' not in log:
+                    log.author = ''
+
                 for changed_path in log.changed_paths:
                     if( changed_path.copyfrom_revision is not None
                     # only include if it has taged an item in the history
@@ -607,17 +621,23 @@ class LogHistoryPanel:
 
         self.button_diff = wx.Button( self.panel_history, id_diff_cmd, " Diff " )
         self.button_diff.Enable( False )
+        self.button_revision_changes = wx.Button( self.panel_history, id_revision_changes_cmd, " Revision Changes " )
+        self.button_revision_changes.Enable( False )
+
 
         # leave View off screen until its implemented
         #self.h_sizer.Add( self.button_view, 0, wx.EXPAND|wx.LEFT, 5 )
         self.h_sizer.Add( self.button_diff, 0, wx.EXPAND|wx.LEFT, 5 )
+        self.h_sizer.Add( self.button_revision_changes, 0, wx.EXPAND|wx.LEFT, 5 )
 
         sizer.Add( self.h_sizer, 0, wx.EXPAND|wx.ALL, 5 )
 
         wx.EVT_BUTTON( self.panel_history, id_view_cmd, self.OnViewCommand )
         wx.EVT_BUTTON( self.panel_history, id_diff_cmd, self.OnDiffCommand )
+        wx.EVT_BUTTON( self.panel_history, id_revision_changes_cmd, self.OnRevisionChangesCommand )
 
         wx.EVT_UPDATE_UI( self.panel_history, id_diff_cmd, self.OnUpdateUiDiffCommand )
+        wx.EVT_UPDATE_UI( self.panel_history, id_revision_changes_cmd, self.OnUpdateUiRevisionChangesCommand )
 
     def getSelectedRows( self ):
         all_rows = []
@@ -751,3 +771,99 @@ class LogHistoryPanel:
                 except StopIteration:
                     # no problem all done
                     break
+
+    def OnUpdateUiRevisionChangesCommand( self, event ):
+        self.button_revision_changes.Enable( len( self.getSelectedRows() ) in (1, 2) )
+
+    def OnRevisionChangesCommand( self, event ):
+        row_indices = self.getSelectedRows()
+
+        info1 = wb_subversion_diff.PathInfoForDiff()
+        info1.path = self.all_filtered_log_entries[ row_indices[0] ].url
+        info2 = info1.copy()
+        if len( row_indices ) == 1:
+            # for one selected revision N, show files modified in revision N
+            # and set the diff range to N-1..N.
+            log_entries = [self.all_filtered_log_entries[ row_indices[0] ]]
+            info1.revision = pysvn.Revision( pysvn.opt_revision_kind.number,
+                                             self.all_filtered_log_entries[ row_indices[0] ].rev_number-1 )
+        else:
+            # for two selected revisions N and M, show files modified in revisions N+1..M
+            # and set the diff range to N..M.
+            # note that all_filtered_log_entries contains lower revisions at higher indices.
+            log_entries = self.all_filtered_log_entries[ row_indices[0]:row_indices[1] ]
+            info1.revision = pysvn.Revision( pysvn.opt_revision_kind.number,
+                                             self.all_filtered_log_entries[ row_indices[1] ].rev_number )
+        info2.revision = pysvn.Revision( pysvn.opt_revision_kind.number,
+                                         self.all_filtered_log_entries[ row_indices[0] ].rev_number )
+        info1.peg_revision = info1.revision
+        info2.peg_revision = info2.revision
+
+        changed_states = {}
+
+        repos_root_url = self.project_info.client_bg.info2( self.project_info.wc_path, recurse=False )[0][1].repos_root_URL
+        prefix_len = len( self.all_filtered_log_entries[row_indices[0]].url ) - len( repos_root_url )
+        for log_entry in log_entries:
+            if log_entry.url == self.all_filtered_log_entries[row_indices[0]].url:
+                for changed_path in log_entry.changed_paths:
+                    repository_path = changed_path['path']
+                    url = repos_root_url + repository_path
+
+                    if changed_states.has_key(repository_path):
+                        branch_text_states = changed_states[repository_path]['branch_text_states']
+                    else:
+                        branch_text_states = ''
+                    branch_text_states += changed_path['action']
+
+                    # Create a new status object from the log entry data.
+                    entry = pysvn.PysvnEntry(
+                                {'checksum': ''
+                                ,'commit_author': log_entry.author
+                                ,'commit_revision': log_entry.rev_number
+                                ,'commit_time': log_entry.date
+                                ,'conflict_new': None
+                                ,'conflict_old': None
+                                ,'conflict_work': None
+                                ,'copy_from_revision': pysvn.Revision( pysvn.opt_revision_kind.number, -1 )
+                                ,'copy_from_url': None
+                                ,'is_absent': 0
+                                ,'is_copied': 0
+                                ,'is_deleted': 0
+                                ,'kind': pysvn.node_kind.file
+                                ,'lock_comment': None
+                                ,'lock_creation_date': 0.0
+                                ,'lock_owner': None
+                                ,'lock_token': None
+                                ,'name': repository_path.split( '/' )[-1]
+                                ,'properties_time': 0.0
+                                ,'property_reject_file': None
+                                ,'repos': repos_root_url
+                                ,'revision': log_entry.rev_number
+                                ,'schedule': pysvn.wc_schedule.normal
+                                ,'text_time': 0.0
+                                ,'url': url
+                                ,'uuid': ''})
+
+                    status = pysvn.PysvnStatus(
+                                {'entry': entry
+                                ,'is_copied': 0
+                                ,'is_locked': 0
+                                ,'is_switched': 0
+                                ,'is_versioned': 1
+                                ,'path': repository_path
+                                ,'prop_status': pysvn.wc_status_kind.normal
+                                ,'repos_lock': None
+                                ,'repos_prop_status': pysvn.wc_status_kind.none
+                                ,'repos_text_status': pysvn.wc_status_kind.none
+                                ,'branch_text_states': branch_text_states
+                                ,'text_status': pysvn.wc_status_kind.normal})
+                    changed_states[repository_path] = status
+            else:
+               self.app.log.info( 'Revision changes for r%d ignored. Its URL "%s" does not match r%d URL "%s".' %
+                                   ( log_entry.rev_number, log_entry.url, 
+                                     self.all_filtered_log_entries[row_indices[0]].rev_number,
+                                     self.all_filtered_log_entries[row_indices[0]].url ) )
+
+        changed_files = [changed_states[status] for status in changed_states]
+
+        self.app.showReportRevisionChangesFrame( self.project_info, changed_files, info1, info2 )
