@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -24,6 +24,7 @@ import wb_subversion_utils
 import wb_subversion_checkin
 import wb_clipboard
 import wb_diff_frame
+import wb_dialogs
 
 class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHandlerCommon):
     def __init__( self, app, list_panel, project_info ):
@@ -65,6 +66,7 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
                 ,('', wb_ids.id_SP_Unlock, 'Unlock...' )
                 ,('-', 0, 0 )
                 ,('', wb_ids.id_SP_Update, 'Update' )
+                ,('', wb_ids.id_SP_Update_To, 'Update to' )
                 ,('-', 0, 0 )
                 ,('', wb_ids.id_SP_Checkin, 'Checkin...' )
                 ,('-', 0, 0 )
@@ -87,6 +89,13 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
             all_clipboard_filenames = []
         return all_clipboard_filenames
 
+    def getBackgroundColour( self ):
+        pi = self.app.frame.tree_panel.getProjectTopProjectInfo()
+        if pi.use_background_colour:
+            return pi.background_colour
+        else:
+            return (255,255,255)
+
     #------------------------------------------------------------
     def Cmd_File_EditCopy( self, all_rows ):
         self.app.setPasteData( wb_clipboard.Clipboard( [self.getFilename( row ) for row in all_rows], is_copy=True ) )
@@ -402,6 +411,8 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
     def Cmd_File_Update( self, all_rows ):
         self.app.setProgress( 'Updated %(count)d', 0 )
 
+        self.project_info.initNotify()
+
         for filename in [self.getFilename( row ) for row in all_rows]:
             self.app.setAction( 'Update %s...' % filename )
 
@@ -430,6 +441,51 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
                     else:
                         self.app.log.info( 'Updated %s to revision %d, %d new updates' % (basename, rev.number, count) )
 
+        if self.project_info.notification_of_files_in_conflict == 1:
+            wx.MessageBox( "%d file is in conflict" % self.project_info.notification_of_files_in_conflict,
+                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+        elif self.project_info.notification_of_files_in_conflict > 1:
+            wx.MessageBox( "%d files are in conflict" % self.project_info.notification_of_files_in_conflict,
+                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+
         self.app.clearProgress()
         self.app.setAction( 'Ready' )
         self.app.refreshFrame()
+
+    def Cmd_File_Update_To( self, all_rows ):
+        dialog = wb_dialogs.UpdateTo( None )
+        if dialog.ShowModal() == wx.ID_OK:
+
+            self.app.setProgress( 'Updated %(count)d', 0 )
+
+            for filename in [self.getFilename( row ) for row in all_rows]:
+                self.app.setAction( 'Update %s...' % filename )
+
+                yield self.app.backgroundProcess
+
+                ok = False
+                try:
+                    rev_list = self.project_info.client_bg.update( filename, False, dialog.getRevision() )
+                    ok = True
+                except pysvn.ClientError, e:
+                    self.app.log_client_error( e )
+
+                yield self.app.foregroundProcess
+
+                if not ok:
+                    break
+
+                for rev in rev_list:
+                    if rev.number > 0:
+                        basename = os.path.basename( filename )
+                        count = self.app.getProgressValue( 'count' )
+                        if count == 0:
+                            self.app.log.info( 'Updated %s to revision %d, no new updates' % (basename, rev.number) )
+                        elif count == 1:
+                            self.app.log.info( 'Updated %s to revision %d, 1 new update' % (basename, rev.number) )
+                        else:
+                            self.app.log.info( 'Updated %s to revision %d, %d new updates' % (basename, rev.number, count) )
+
+            self.app.clearProgress()
+            self.app.setAction( 'Ready' )
+            self.app.refreshFrame()
