@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -152,6 +152,9 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         except pysvn.ClientError, e:
             print 'Error: %s' % e.args[0]
 
+    def getBackgroundColour( self ):
+        return (255,255,255)
+
     def getBranchOriginRevision( self ):
         if self.__branch_origin_revision is None:
             try:
@@ -295,7 +298,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
     def __restoreListSelectionState( self, (focused_filename, all_selected_filenames) ):
         g = self.list_panel.list_ctrl
 
-        self.app.log.debug( '__restoreListSelectionState %r %r' % (focused_filename, all_selected_filenames) )
+        self.app.log.debug( '__restoreListSelectionState In %r %r' % (focused_filename, all_selected_filenames) )
 
         focused_index = 0
         g.SetItemCount( len(self.all_files) )
@@ -311,6 +314,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         if len(self.all_files) > 0:
             g.EnsureVisible( focused_index )
 
+        self.app.log.debug( '__restoreListSelectionState Out %r' % (len(self.all_files),) )
+
     def __focusedRow( self ):
         g = self.list_panel.list_ctrl
         for index in range( len( self.all_files ) ):
@@ -328,11 +333,14 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
     def getColumnId( self, col ):
         return self.column_info.getColumnOrder()[col]
 
-    def OnGetItemText( self, index, col ):
+    def _getNameColPrefix( self ):
         prefix_len = len( self.project_info.wc_path )
         if not self.project_info.wc_path.endswith( os.sep ):
             prefix_len += 1
 
+        return prefix_len
+
+    def OnGetItemText( self, index, col ):
         column = self.column_info.getNameByColumn( col )
 
         if self.project_info.need_checkout:
@@ -347,29 +355,41 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         status = self.all_files[ index ]
 
         if column == self.col_name:
-            value = self.__get_NameColumn( status, prefix_len )
+            value = self.__get_NameColumn( status, self._getNameColPrefix() )
+
         elif column == self.col_state:
             value = self.__get_StateColumn( status )
+
         elif column == self.col_date:
             value = self.__get_DateColumn( status )
+
         elif column == self.col_revision:
             value = self.__get_RevisionColumn( status )
+
         elif column == self.col_author:
             value = self.__get_AuthorColumn( status )
+
         elif column == self.col_type:
             value = self.__get_TypeColumn( status )
+
         elif column == self.col_size:
             value = self.__get_SizeColumn( status )
+
         elif column == self.col_mime_type:
             value = self.__get_MimeTypeColumn( self.project_info.getProperty( status.path, 'svn:mime-type' ) )
+
         elif column == self.col_eol_style:
             value = self.__get_EolStyleColumn( self.project_info.getProperty( status.path, 'svn:eol-style' ) )
+
         elif column == self.col_lock_owner:
             value = self.__get_LockOwnerColumn( status )
+
         elif column == self.col_lock_comment:
             value = self.__get_LockCommentColumn( status )
+
         else:
             value = 'Opss'
+
         return value
 
     def OnGetItemAttr( self, index ):
@@ -432,6 +452,9 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         return value
 
     def __get_StateColumn( self, status ):
+        if status.path in self.getAllGreyFilenames():
+            return '--'
+
         return self.statusFormatString( status )
 
     def __get_TypeColumn( self, status ):
@@ -511,7 +534,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                 state.is_folder = False
 
             text_status = self.getTextStatus( row )
-            if text_status in [pysvn.wc_status_kind.unversioned]:
+            if text_status in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
                 state.versioned = False
 
             if text_status not in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
@@ -579,24 +602,21 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         if status.entry is None:
             return ''
         else:
-            return os.path.join( self.project_info.wc_path,
-                    status.entry.conflict_old )
+            return os.path.join( os.path.dirname( status.path ), status.entry.conflict_old )
 
     def getConflictNew( self, row_or_status ):
         status = self.getStatusFromRowOrStatus( row_or_status )
         if status.entry is None:
             return ''
         else:
-            return os.path.join( self.project_info.wc_path,
-                    status.entry.conflict_new )
+            return os.path.join( os.path.dirname( status.path ), status.entry.conflict_new )
 
     def getConflictMine( self, row_or_status ):
         status = self.getStatusFromRowOrStatus( row_or_status )
         if status.entry is None:
             return ''
         else:
-            return os.path.join( self.project_info.wc_path,
-                    status.entry.conflict_work )
+            return os.path.join( os.path.dirname( status.path ), status.entry.conflict_work )
 
     def getTextStatus( self, row_or_status ):
         status = self.getStatusFromRowOrStatus( row_or_status )
