@@ -54,6 +54,8 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         self.tags_url = None
         self.branches_url = None
 
+        self.notification_of_files_in_conflict = 0
+
     def __repr__( self ):
         return '<svn.ProjectInfo wc_path=%r>' % self.wc_path
         #return '<wb_subversion_provider.ProjectInfo url=%s, wc_path=%s>' % (self.url, self.wc_path)
@@ -72,18 +74,16 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             # need one client/project/thread
             self.client_fg = pysvn.Client()
             self.client_fg.exception_style = 1
-            self.client_fg.callback_notify = wb_exceptions.TryWrapper(
-                                    self.app.log, self.callback_notify )
-            self.client_fg.callback_get_login = wb_exceptions.TryWrapper(
-                                    self.app.log, self.app.getCredentials )
-            self.client_fg.callback_ssl_server_trust_prompt = wb_exceptions.TryWrapper(
-                                    self.app.log, self.getServerTrust )
+            self.client_fg.callback_get_login = wb_exceptions.TryWrapper( self.app.log, self.app.getCredentials )
+            self.client_fg.callback_ssl_server_trust_prompt = wb_exceptions.TryWrapper( self.app.log, self.getServerTrust )
+
             self.client_bg = pysvn.Client()
             self.client_bg.exception_style = 1
-            self.client_bg.callback_notify = wb_exceptions.TryWrapper( self.app.log, self.callback_notify )
             self.client_bg.callback_get_login = CallFunctionOnMainThread( self.app, self.app.getCredentials )
             self.client_bg.callback_ssl_server_trust_prompt = CallFunctionOnMainThread( self.app, self.getServerTrust )
 
+            self.initNotify()
+
         self.tags_url = kws.get( 'tags_url', '' )
         self.branches_url = kws.get( 'branches_url', '' )
 
@@ -129,6 +129,11 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         label_url_parts.extend( suffix_parts[0:wild_parts] )
         return '/'.join( label_url_parts )
 
+    def initNotify( self ):
+        self.notification_of_files_in_conflict = 0
+        self.client_fg.callback_notify = wb_exceptions.TryWrapper( self.app.log, self.callback_notify )
+        self.client_bg.callback_notify = wb_exceptions.TryWrapper( self.app.log, self.callback_notify )
+
     def callback_notify( self, arg_dict ):
         # must send messages to the foreground thread to do IO or Linux pthreads hangs
 
@@ -164,8 +169,15 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             # count the interesting update event
             self.app.foregroundProcess( self.app.incProgress, () )
 
+        # count the number of files in conflict
+        action_letter = wb_subversion_utils.wc_notify_action_map[ action ]
+        if( arg_dict['content_state'] == pysvn.wc_notify_state.conflicted
+        or arg_dict['prop_state'] == pysvn.wc_notify_state.conflicted ):
+            action_letter = 'C'
+            self.notification_of_files_in_conflict += 1
+
         # print anything that gets through the filter
-        msg = '%s %s\n' % (wb_subversion_utils.wc_notify_action_map[ action ], arg_dict['path'])
+        msg = '%s %s\n' % (action_letter, arg_dict['path'])
         self.app.foregroundProcess( sys.stdout.write, (msg,) )
 
     def readPreferences( self, get_option ):
@@ -255,7 +267,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             entry = self.client_fg.info( self.wc_path )
         except pysvn.ClientError, e:
             # is it the  'is not a working copy' error?
-            if e.args[1][0][1] == 155007:
+            if e.args[1][0][1] == pysvn.svn_err.wc_not_directory:
                 return
 
             print 'Error: %s' % e.args[0]
@@ -281,21 +293,36 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         self.all_files_status = self.filterFilenames( self.all_files_status )
 
         if self.need_properties:
-            if _fast_proplist:
-                for status in self.all_files_status:
-                    if status.is_versioned:
-                        self.files_properties[ status.path ] = self.__proplist( status.path )
-            else:
+            # see if the depth API is available
+            if hasattr( pysvn, 'depth' ):
                 try:
-                    name_list = [status.path for status in self.all_files_status if status.is_versioned]
-                    path_properties = self.client_fg.proplist( name_list, recurse=False )
+                    if p.view_recursive:
+                        path_properties = self.client_fg.proplist( self.wc_path, depth=pysvn.depth.infinity )
+                    else:
+                        path_properties = self.client_fg.proplist( self.wc_path, depth=pysvn.depth.immediates )
 
                     for path, prop_dict in path_properties:
-                        self.files_properties[ path ] = prop_dict
+                        self.files_properties[ os.path.abspath( path ) ] = prop_dict
 
                 except pysvn.ClientError, e:
                     pass
 
+            else:
+                if _fast_proplist:
+                    for status in self.all_files_status:
+                        if status.is_versioned:
+                            self.files_properties[ os.path.abspath( status.path ) ] = self.__proplist( status.path )
+                else:
+                    try:
+                        name_list = [status.path for status in self.all_files_status if status.is_versioned]
+                        path_properties = self.client_fg.proplist( name_list, recurse=False )
+
+                        for path, prop_dict in path_properties:
+                            self.files_properties[ os.path.abspath( path ) ] = prop_dict
+
+                    except pysvn.ClientError, e:
+                        pass
+
         if p.view_recursive:
             wc_path_num_parts = len( self.wc_path.split( os.sep ) ) + 1
             self.all_tree_files_status = []
@@ -330,7 +357,8 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
 
     def getProperty( self, filename, propname ):
         d = self.files_properties.get( filename, {} )
-        return d.get( propname, None )
+        prop = d.get( propname, None )
+        return prop
 
     def getTreeFilesStatus( self ):
         return self.all_tree_files_status
