@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -105,7 +105,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         elif not os.path.exists( dir_status.path ):
             # nothing there
             return wb_config.colour_status_need_checkout
-        elif dir_status.text_status in [pysvn.wc_status_kind.unversioned]:
+        elif dir_status.text_status in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
             # unversioned
             return wb_config.colour_status_unversioned
 
@@ -117,7 +117,6 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
         dir_status = self.project_info.getDirStatus()
 
-
         state.is_project_parent = self.is_project_parent
 
         if dir_status is None:
@@ -129,6 +128,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             state.need_checkout = True
             state.conflict = False
             state.file_exists = False
+
         else:
             state.modified = True
             state.new_versioned = True
@@ -139,12 +139,11 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             state.conflict = True
             state.file_exists = True
 
-            filename = dir_status.path
-            if not os.path.exists( filename ):
+            if not os.path.exists( dir_status.path ):
                 state.file_exists = False
 
             text_status = dir_status.text_status
-            if text_status in [pysvn.wc_status_kind.unversioned]:
+            if text_status in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
                 state.versioned = False
             else:
                 state.unversioned = False
@@ -153,17 +152,17 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
             prop_status = dir_status.prop_status
             state.modified = (text_status in [pysvn.wc_status_kind.modified,
-                                pysvn.wc_status_kind.conflicted]
-                        or
-                        prop_status in [pysvn.wc_status_kind.modified,
-                                pysvn.wc_status_kind.conflicted])
-            state.need_checkin = (text_status in [pysvn.wc_status_kind.added,
-                                    pysvn.wc_status_kind.deleted,
-                                    pysvn.wc_status_kind.modified]
+                                                pysvn.wc_status_kind.conflicted]
                             or
-                            prop_status in [pysvn.wc_status_kind.added,
-                                    pysvn.wc_status_kind.deleted,
-                                    pysvn.wc_status_kind.modified])
+                                prop_status in [pysvn.wc_status_kind.modified,
+                                                pysvn.wc_status_kind.conflicted])
+            state.need_checkin = (text_status in [pysvn.wc_status_kind.added,
+                                                    pysvn.wc_status_kind.deleted,
+                                                    pysvn.wc_status_kind.modified]
+                                or
+                                    prop_status in [pysvn.wc_status_kind.added,
+                                                    pysvn.wc_status_kind.deleted,
+                                                    pysvn.wc_status_kind.modified])
             state.conflict = text_status in [pysvn.wc_status_kind.conflicted]
 
         return state
@@ -183,6 +182,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             menu_item += [('', wb_ids.id_SP_Checkout, 'Checkout' )]
         else:
             menu_item += [('', wb_ids.id_SP_Update, 'Update' )]
+            menu_item += [('', wb_ids.id_SP_Update_To, 'Update to' )]
         menu_item += [('-', 0, '' )
             ,('', wb_ids.id_SP_Checkin, 'Checkin...' )
             ,('-', 0, 0 )
@@ -255,12 +255,13 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
     def Cmd_Dir_Add( self ):
         name = os.path.basename( self.project_info.wc_path )
-        force = self.app.addFile( 'Add Directory', name, False )
+        force, recursive = self.app.addFolder( 'Add Folder', name, force=False, recursive=True )
         if force is None:
             return
 
         try:
-            self.project_info.client_fg.add( self.project_info.wc_path, recurse=True, force=force )
+            self.project_info.client_fg.add( self.project_info.wc_path, force=force, recurse=recursive )
+
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
@@ -759,7 +760,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             new_full_filename = os.path.join( os.path.dirname( old_filename ), new_name )
             dir_status = self.project_info.getDirStatus()
             print 'Rename',old_filename, new_full_filename
-            if dir_status is None or dir_status.text_status not in [pysvn.wc_status_kind.unversioned]:
+            if dir_status is None or dir_status.text_status not in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
                 try:
                     self.project_info.client_fg.move( old_filename, new_full_filename, force=force )
                 except pysvn.ClientError, e:
@@ -799,6 +800,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         filename = self.project_info.wc_path
         ok = False
         try:
+            self.project_info.initNotify()
             rev_list = self.project_info.client_bg.update( filename, recurse=True )
             ok = True
         except pysvn.ClientError, e:
@@ -819,10 +821,53 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                 else:
                     self.app.log.warning( 'Already up to date' )
 
+
+            if self.project_info.notification_of_files_in_conflict == 1:
+                wx.MessageBox( "%d file is in conflict" % self.project_info.notification_of_files_in_conflict,
+                    "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+            elif self.project_info.notification_of_files_in_conflict > 1:
+                wx.MessageBox( "%d files are in conflict" % self.project_info.notification_of_files_in_conflict,
+                    "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+
         self.app.clearProgress()
         self.app.setAction( 'Ready' )
         self.app.refreshFrame()
 
+    def Cmd_Dir_Update_To( self ):
+        dialog = wb_dialogs.UpdateTo( None )
+        if dialog.ShowModal() == wx.ID_OK:
+            self.app.setAction( 'Update %s...' % self.project_info.wc_path )
+            self.app.setProgress( 'Updated %(count)d', 0 )
+
+            yield self.app.backgroundProcess
+
+            filename = self.project_info.wc_path
+            ok = False
+            try:
+                rev_list = self.project_info.client_bg.update( filename, True, dialog.getRevision() )
+                ok = True
+            except pysvn.ClientError, e:
+                self.app.log_client_error( e )
+
+            yield self.app.foregroundProcess
+
+            if ok:
+                for rev in rev_list:
+                    if rev.number > 0:
+                        count = self.app.getProgressValue( 'count' )
+                        if count == 0:
+                            self.app.log.info( 'Updated %s to revision %d, no new updates' % (filename, rev.number) )
+                        elif count == 1:
+                            self.app.log.info( 'Updated %s to revision %d, 1 new update' % (filename, rev.number) )
+                        else:
+                            self.app.log.info( 'Updated %s to revision %d, %d new updates' % (filename, rev.number, count) )
+                    else:
+                        self.app.log.warning( 'Already up to date' )
+
+            self.app.clearProgress()
+            self.app.setAction( 'Ready' )
+            self.app.refreshFrame()
+
     def Cmd_Dir_Copy( self, all_filenames ):
         try:
             for src_filename in all_filenames:
