@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -85,6 +85,7 @@ class WbTreePanel(wx.Panel):
                 (wx.ACCEL_CMD, ord('I'), wb_ids.id_SP_Info),
                 (wx.ACCEL_CMD, ord('P'), wb_ids.id_SP_Properties),
                 (wx.ACCEL_CMD, ord('R'), wb_ids.id_SP_Revert),
+                (wx.ACCEL_CMD, ord('T'), wb_ids.id_SP_Update_To),
                 (wx.ACCEL_CMD, ord('U'), wb_ids.id_SP_Update),
                 (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
                 (wx.ACCEL_CMD, ord('O'), wb_ids.id_Shell_Open),
@@ -170,6 +171,8 @@ class WbTreePanel(wx.Panel):
         else:
             self.gotoBookmark( self.last_position_bookmark_name )
 
+        self.list_panel.firstTimeSelect()
+
     def OnSetFocus( self, event ):
         if wb_config.debug_selection: print 'ZT: WbTreePanel OnSetFocus'
         self.frame.setEventHandler( self )
@@ -568,13 +571,12 @@ class WbTreePanel(wx.Panel):
         menu = handler.getContextMenu( self.frame.ui_state_tree )
         if handler.isProjectParent():
             menu.AppendSeparator()
-            menu.Append( wb_ids.id_Project_Update, 'Update Project' )
+            menu.Append( wb_ids.id_Project_Update, 'Project Settings' )
             menu.Append( wb_ids.id_Project_Delete, 'Delete Project' )
 
         self.tree_ctrl.PopupMenu( menu, point )
         menu.Destroy()
 
-
     def OnProjectAdd( self, event ):
         dialog = wb_project_dialogs.AddProjectDialog( self.app, self )
         rc = dialog.ShowModal()
@@ -760,6 +762,9 @@ class WbTreePanel(wx.Panel):
     def OnSpUpdate( self ):
         return self.Sp_Dispatch( 'Cmd_Dir_Update' )
 
+    def OnSpUpdateTo( self ):
+        return self.Sp_Dispatch( 'Cmd_Dir_Update_To' )
+
     #----------------------------------------
     def OnSpCopy( self, filename_list ):
         return self.Sp_DispatchDrop( 'Cmd_Dir_Copy', filename_list )
